@@ -12,7 +12,7 @@ Configuration file format: YAML
 
 import os
 from pathlib import Path
-from typing import Any, Dict, Optional
+from typing import Any, Optional
 
 try:
     import yaml  # type: ignore[import-untyped]
@@ -28,18 +28,18 @@ class ChatConfig:
     # Default configuration
     DEFAULTS = {
         "colors": {
-            "user": "\033[97m",  # Bright white
-            "agent": "\033[94m",  # Bright blue
-            "system": "\033[33m",  # Yellow
-            "error": "\033[91m",  # Bright red
-            "success": "\033[92m",  # Bright green
-            "dim": "\033[2m",  # Dim
-            "reset": "\033[0m",  # Reset
+            "user": "bright_white",
+            "agent": "bright_blue",
+            "system": "yellow",
+            "error": "bright_red",
+            "success": "bright_green",
+            "dim": "\033[2m",  # Dim (no named equivalent)
+            "reset": "\033[0m",  # Reset (no named equivalent)
         },
         "features": {
-            "auto_save": False,
+            "auto_save": True,
             "rich_enabled": True,
-            "show_tokens": False,
+            "show_tokens": True,
             "show_metadata": True,
             "readline_enabled": True,
         },
@@ -57,12 +57,19 @@ class ChatConfig:
             "show_banner": True,
             "show_thinking_indicator": True,
             "show_duration": True,
-            "show_status_bar": False,
+            "show_status_bar": True,
+            "update_terminal_title": True,
         },
         "audio": {
             "enabled": True,
             "notification_sound": None,  # Uses bundled notification.wav if None
         },
+        "harmony": {
+            # Enable harmony processing (auto-detects by default, set to True to force)
+            "enabled": None,  # None = auto-detect, True = force enable, False = disable
+            # Show reasoning/analysis/commentary channels
+            "show_detailed_thinking": True,
+        },
         # Per-agent overrides (example structure)
         "agents": {
             # 'Complex Coding Clara': {
@@ -80,7 +87,7 @@ class ChatConfig:
         """
         self.config = self._load_config(config_path)
 
-    def _load_config(self, explicit_path: Optional[Path] = None) -> Dict[str, Any]:
+    def _load_config(self, explicit_path: Optional[Path] = None) -> dict[str, Any]:
         """
         Load configuration with hierarchical precedence.
 
@@ -136,13 +143,13 @@ class ChatConfig:
 
         return config
 
-    def _deep_copy(self, d: Dict) -> Dict:
+    def _deep_copy(self, d: dict) -> dict:
         """Deep copy a dictionary."""
         import copy
 
         return copy.deepcopy(d)
 
-    def _merge_config(self, base: Dict, override: Dict) -> Dict:
+    def _merge_config(self, base: dict, override: dict) -> dict:
         """
         Recursively merge override config into base config.
 
@@ -199,7 +206,7 @@ class ChatConfig:
         value = self._get_nested(self.config, key)
         return value if value is not None else default
 
-    def _get_nested(self, d: Dict, key: str) -> Any:
+    def _get_nested(self, d: dict, key: str) -> Any:
         """
         Get nested dictionary value using dot notation.
 
@@ -223,7 +230,7 @@ class ChatConfig:
 
     def get_section(
         self, section: str, agent_name: Optional[str] = None
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """
         Get entire configuration section with agent overrides applied.
 
@@ -342,9 +349,9 @@ colors:
 # FEATURES - Toggle optional functionality
 # ============================================================================
 features:
-  auto_save: false              # Automatically save conversations on exit
+  auto_save: true               # Automatically save conversations on exit
   rich_enabled: true            # Use rich library for formatting (if available)
-  show_tokens: false            # Display token counts and cost estimates
+  show_tokens: true             # Display token counts and cost estimates
   show_metadata: true           # Show agent metadata on startup
   readline_enabled: true        # Enable command history with readline
 
@@ -371,7 +378,7 @@ ui:
   show_banner: true            # Show welcome banner on startup
   show_thinking_indicator: true  # Show "Thinking..." spinner
   show_duration: true          # Show query duration
-  show_status_bar: false       # Show status bar at top (agent, model, queries, time)
+  show_status_bar: true        # Show status bar at top (agent, model, queries, time)
 
 # ============================================================================
 # AUDIO - Notification sounds
@@ -380,6 +387,19 @@ audio:
   enabled: true                # Play sound when agent completes a turn
   notification_sound: null     # Path to custom WAV file (uses bundled sound if null)
 
+# ============================================================================
+# HARMONY - OpenAI Harmony format settings (for gpt-oss models)
+# ============================================================================
+harmony:
+  enabled: auto                 # Enable harmony processing (auto/yes/no)
+                                # auto (default) = Auto-detect harmony agents
+                                # yes = Force enable for all agents
+                                # no = Disable harmony processing
+  show_detailed_thinking: true  # Show reasoning/analysis/commentary with prefixes
+                                # When true (default), displays internal reasoning,
+                                # analysis, and commentary channels with labeled
+                                # prefixes. When false, only shows final response
+
 # ============================================================================
 # PER-AGENT OVERRIDES
 # ============================================================================
