@@ -40,7 +40,7 @@ import stat
 import sys
 import time
 from pathlib import Path
-from typing import Any, Dict, Optional
+from typing import Any, Optional
 
 import pyperclip
 
@@ -74,6 +74,7 @@ from .components import (
     ConfigWizard,
     DependencyManager,
     DisplayManager,
+    HarmonyProcessor,
     SessionManager,
     StatusBar,
     TemplateManager,
@@ -421,7 +422,7 @@ class ChatLoop:
         self.last_query = ""  # Track last user query for copy command
 
         # Conversation tracking for auto-save
-        self.conversation_history: list[Dict[str, Any]] = []
+        self.conversation_history: list[dict[str, Any]] = []
 
         # Generate session ID for this chat session
         from datetime import datetime
@@ -541,7 +542,8 @@ class ChatLoop:
                 if model_override:
                     model_info = model_override
 
-            # Shorten long model IDs
+            # Shorten long model IDs (ensure it's a string first)
+            model_info = str(model_info) if model_info else "Unknown Model"
             if len(model_info) > 30:
                 model_info = model_info[:27] + "..."
 
@@ -593,7 +595,60 @@ class ChatLoop:
         )
         self.session_manager = SessionManager(sessions_dir=sessions_dir)
 
-    def _extract_token_usage(self, response_obj) -> Optional[Dict[str, int]]:
+        # Setup Harmony processor if agent uses Harmony format
+        self.harmony_processor = None
+
+        # Check if harmony should be enabled
+        # Priority: config override > auto-detection
+        harmony_enabled_config = (
+            self.config.get("harmony.enabled", None) if self.config else None
+        )
+        uses_harmony = self.agent_metadata.get("uses_harmony", False)
+
+        logger.debug(f"Harmony config value: {harmony_enabled_config}")
+        logger.debug(f"Auto-detected harmony: {uses_harmony}")
+
+        # Determine if harmony should be enabled
+        # None = auto-detect, True = force enable, False = force disable
+        should_enable_harmony = (
+            harmony_enabled_config
+            if harmony_enabled_config is not None
+            else uses_harmony
+        )
+
+        logger.debug(f"Should enable harmony: {should_enable_harmony}")
+
+        if should_enable_harmony:
+            # Get detailed thinking config option
+            show_detailed = (
+                self.config.get("harmony.show_detailed_thinking", True)
+                if self.config
+                else True
+            )
+            self.harmony_processor = HarmonyProcessor(
+                show_detailed_thinking=show_detailed
+            )
+
+            # Log how harmony was enabled
+            if harmony_enabled_config is True:
+                logger.info(
+                    f"✓ Harmony ENABLED via config override "
+                    f"(detailed_thinking={show_detailed})"
+                )
+            elif harmony_enabled_config is False:
+                logger.info("✗ Harmony DISABLED via config override")
+            else:
+                logger.info(
+                    f"✓ Harmony AUTO-DETECTED and enabled "
+                    f"(detailed_thinking={show_detailed})"
+                )
+        else:
+            logger.info(
+                "✗ Harmony NOT enabled "
+                "(agent not detected as harmony, config not set)"
+            )
+
+    def _extract_token_usage(self, response_obj) -> Optional[dict[str, int]]:
         """
         Extract token usage from response object.
 
@@ -721,9 +776,7 @@ class ChatLoop:
         lines.append("\n---\n")
 
         for i, entry in enumerate(self.conversation_history, 1):
-            timestamp = datetime.fromtimestamp(entry["timestamp"]).strftime(
-                "%H:%M:%S"
-            )
+            timestamp = datetime.fromtimestamp(entry["timestamp"]).strftime("%H:%M:%S")
             lines.append(f"\n## Query {i} ({timestamp})\n")
             lines.append(f"**You:** {entry['query']}\n")
             lines.append(f"**{self.agent_name}:**\n\n{entry['response']}\n")
@@ -1098,7 +1151,7 @@ class ChatLoop:
                 while not stop_event.is_set():
                     await asyncio.sleep(0.1)
 
-    async def _stream_agent_response(self, query: str) -> Dict[str, Any]:
+    async def _stream_agent_response(self, query: str) -> dict[str, Any]:
         """
         Stream agent response asynchronously.
 
@@ -1212,17 +1265,47 @@ class ChatLoop:
             full_response = "".join(response_text)
             self.last_response = full_response
 
-            if self.use_rich and full_response.strip() and self.console:
+            # Process through Harmony if available
+            display_text = full_response
+            if self.harmony_processor:
+                # Debug: Log response object structure
+                logger.debug(f"Response object type: {type(response_obj)}")
+                logger.debug(f"Response object attrs: {dir(response_obj)[:20]}")
+                if hasattr(response_obj, "choices"):
+                    logger.debug(
+                        f"Response has choices: {len(response_obj.choices)}"
+                    )
+                    if response_obj.choices:
+                        choice = response_obj.choices[0]
+                        logger.debug(f"Choice type: {type(choice)}")
+                        logger.debug(f"Choice attrs: {dir(choice)[:20]}")
+                        if hasattr(choice, "logprobs"):
+                            logger.debug(f"Has logprobs: {choice.logprobs is not None}")
+                        if hasattr(choice, "message"):
+                            logger.debug(f"Message type: {type(choice.message)}")
+
+                processed = self.harmony_processor.process_response(
+                    full_response, metadata=response_obj
+                )
+                display_text = self.harmony_processor.format_for_display(processed)
+
+                # Log if Harmony-specific features detected
+                if processed.get("has_reasoning"):
+                    logger.debug("Harmony response contains reasoning")
+                if processed.get("has_tools"):
+                    logger.debug("Harmony response contains tool calls")
+
+            if self.use_rich and display_text.strip() and self.console:
                 # Use rich markdown rendering
                 print()  # New line after agent name
-                md = Markdown(full_response)
+                md = Markdown(display_text)
                 self.console.print(md)
             elif not self.use_rich and response_text:
                 # Already printed during streaming, just add newline
                 if not first_token_received:
                     # Non-streaming case where nothing was printed yet
                     # Apply colorization for tool messages
-                    formatted_response = Colors.format_agent_response(full_response)
+                    formatted_response = Colors.format_agent_response(display_text)
                     print(formatted_response)
 
             duration = time.time() - start_time
